#define USE_ARDUINO_INTERRUPTS true

#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>
#include <Wire.h>
#include <SPI.h>
#include <PulseSensorPlayground.h>

#define SCREEN_WIDTH 128
#define SCREEN_HEIGHT 64

#define PULSEWIRE 0
#define THRESHOLD 550

#define OLED_CLK 12
#define OLED_MOSI 6
#define OLED_RESET 8
#define OLED_DC 9
#define OLED_CS 10

Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT,
  OLED_MOSI, OLED_CLK, OLED_DC, OLED_RESET, OLED_CS);

PulseSensorPlayground pulseSensor;
int BPM;

int buttonTakePulse = 7;
int buttonSendData = 13;

static const unsigned char PROGMEM logo2_bmp[] =
{ 0x03, 0xC0, 0xF0, 0x06, 0x71, 0x8C, 0x0C, 0x1B, 0x06, 0x18, 0x0E, 0x02, 0x10, 0x0C, 0x03, 0x10,           
0x04, 0x01, 0x10, 0x04, 0x01, 0x10, 0x40, 0x01, 0x10, 0x40, 0x01, 0x10, 0xC0, 0x03, 0x08, 0x88,
0x02, 0x08, 0xB8, 0x04, 0xFF, 0x37, 0x08, 0x01, 0x30, 0x18, 0x01, 0x90, 0x30, 0x00, 0xC0, 0x60,
0x00, 0x60, 0xC0, 0x00, 0x31, 0x80, 0x00, 0x1B, 0x00, 0x00, 0x0E, 0x00, 0x00, 0x04, 0x00,  }; // inima mica

static const unsigned char PROGMEM logo3_bmp[] =
{ 0x01, 0xF0, 0x0F, 0x80, 0x06, 0x1C, 0x38, 0x60, 0x18, 0x06, 0x60, 0x18, 0x10, 0x01, 0x80, 0x08,
0x20, 0x01, 0x80, 0x04, 0x40, 0x00, 0x00, 0x02, 0x40, 0x00, 0x00, 0x02, 0xC0, 0x00, 0x08, 0x03,
0x80, 0x00, 0x08, 0x01, 0x80, 0x00, 0x18, 0x01, 0x80, 0x00, 0x1C, 0x01, 0x80, 0x00, 0x14, 0x00,
0x80, 0x00, 0x14, 0x00, 0x80, 0x00, 0x14, 0x00, 0x40, 0x10, 0x12, 0x00, 0x40, 0x10, 0x12, 0x00,
0x7E, 0x1F, 0x23, 0xFE, 0x03, 0x31, 0xA0, 0x04, 0x01, 0xA0, 0xA0, 0x0C, 0x00, 0xA0, 0xA0, 0x08,
0x00, 0x60, 0xE0, 0x10, 0x00, 0x20, 0x60, 0x20, 0x06, 0x00, 0x40, 0x60, 0x03, 0x00, 0x40, 0xC0,
0x01, 0x80, 0x01, 0x80, 0x00, 0xC0, 0x03, 0x00, 0x00, 0x60, 0x06, 0x00, 0x00, 0x30, 0x0C, 0x00,
0x00, 0x08, 0x10, 0x00, 0x00, 0x06, 0x60, 0x00, 0x00, 0x03, 0xC0, 0x00, 0x00, 0x01, 0x80, 0x00  }; // inima mare

int LEDR = 5;
int LEDG = 4;
int LEDB = 2;

void setup() {  
  Serial.begin(9600);
  display.begin(SSD1306_SWITCHCAPVCC, 0x3C); //Start OLED display
  display.display();
  delay(3000);

  // Initialize sensor
  pulseSensor.analogInput(PULSEWIRE);
  pulseSensor.setThreshold(THRESHOLD); 
  pulseSensor.blinkOnPulse(13);
  pulseSensor.begin();
  
  pinMode(buttonTakePulse, INPUT_PULLUP);
  pinMode(buttonSendData, INPUT_PULLUP);
 
  pinMode(LEDR, OUTPUT);
  pinMode(LEDG, OUTPUT);
  pinMode(LEDB, OUTPUT);
}

void RGB_color(int red, int green, int blue) {
  analogWrite(LEDR, red);
  analogWrite(LEDG, green);
  analogWrite(LEDB, blue);
}

void loop() {
   int buttonState1 = digitalRead(buttonTakePulse);
   int buttonState2 = digitalRead(buttonSendData);
 
  if (buttonState1 == LOW) {
    display.clearDisplay();
    display.setTextSize(2);
    display.setTextColor(WHITE); 
    display.setCursor(0,0);                
    display.println("   Press");
    display.println(" button to");
    display.println(" take your");
    display.println("   pulse!");
    display.display();

    RGB_color(0, 0, 0);
    
  } else if (buttonState1 == HIGH) {
    BPM = pulseSensor.getBeatsPerMinute();
  
    display.clearDisplay();
    display.drawBitmap(5, 5, logo2_bmp, 24, 21, WHITE);
    display.setTextSize(2);
    display.setTextColor(WHITE); 
    display.setCursor(50,0);                
    display.println("BPM");             
    display.setCursor(50,18);                
    display.println(BPM); 
    display.display();
    RGB_color(255, 255, 255);
    delay(1000);

    if (pulseSensor.sawStartOfBeat()) {
      display.clearDisplay();                          
      display.drawBitmap(0, 0, logo3_bmp, 32, 32, WHITE);
      display.setTextSize(2);
      display.setTextColor(WHITE); 
      display.setCursor(50,0);                
      display.println("BPM");             
      display.setCursor(50,18);                
      display.println(BPM);
      display.display();
      Serial.println(BPM);
      tone(3,1000);                                      
      delay(100);
      noTone(3);

      if (BPM > 100) {
        RGB_color(255, 0, 0);
      } else {
        if (BPM > 60) {
          RGB_color(0, 255, 0);
        } else {
          RGB_color(255, 255, 0);
        }
      }
      delay(1000);

    }
  }
  if (buttonState2 == HIGH){
    Serial.println("gata");
  } else {
    RGB_color(0, 0, 0);
  }
  
}

